@@ -216,7 +216,7 @@ impl ErrorMessage {
         TOOL_OVERVIEW,
       ),
       RuleNotFound(id) => Self::new(
-        format!("Rule not found: {}", id),
+        format!("Rule not found: {id}"),
         format!("Rule with id '{id}' not found in project configuration. Please make sure it exists."),
         TOOL_OVERVIEW,
       ),
